
    ▄█▄     ▄  █ ██   ████▄    ▄▄▄▄▄   █▀▄▀█ ▄███▄      ▄▄▄▄▀ ▄███▄   █▄▄▄▄
    █▀ ▀▄  █   █ █ █  █   █   █     ▀▄ █ █ █ █▀   ▀  ▀▀▀ █    █▀   ▀  █  ▄▀
    █   ▀  ██▀▀█ █▄▄█ █   █ ▄  ▀▀▀▀▄   █ ▄ █ ██▄▄        █    ██▄▄    █▀▀▌
    █▄  ▄▀ █   █ █  █ ▀████  ▀▄▄▄▄▀    █   █ █▄   ▄▀    █     █▄   ▄▀ █  █
    ▀███▀     █     █                     █  ▀███▀     ▀      ▀███▀     █
             ▀     █                     ▀                             ▀
                  ▀


# ChaosMeter 

Java Metrics Calculator 
(Currently supporting Mutant Density, Cyclomatic Complexity, and SLOC)

*Copyright (C) 2020 Ali Parsai*

## How to Use:
On your selected python platform use:

    pip3 install chaosmeter

You can use the program by executing it as a module:

    python3 -m chaosmeter [options]

For a java project, all you need to do is to pass the required arguments to ChaosMeter:

    python3 -m chaosmeter  -p [path to source code] -t [path to target results]


------------------------------------------------------------------------------------
## License
This program is free software: you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by the Free Software 
Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT 
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

------------------------------------------------------------------------------------
Find me at:

[parsai.net](http://www.parsai.net)

------------------------------------------------------------------------------------


